@@ -1,8 +1,8 @@
 __title__ = 'fileblock'
 __description__ = 'simplify file processing'
-__version__ = '1.1.0.2022.3.3'
+__version__ = '1.3.0.2022.4.27'
 __url__ = "http://github.com/miaobuao/fileblock"
-__author__ = '喵不嗷|miaobuao'
+__author__ = 'miaobuao'
 __author_email__ = '617802189@qq.com'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2022 miaobuao'
\ No newline at end of file
